==> camunda-dmn-model-7.6.0-test-sources.jar: org/camunda/bpm/model/dmn/instance/DecisionTest.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.camunda.bpm.model.dmn.instance;

import java.util.Arrays;
import java.util.Collection;

public class DecisionTest extends DmnModelElementInstanceTest {

  public TypeAssumption getTypeAssumption() {
    return new TypeAssumption(DrgElement.class, false);
  }

  public Collection<ChildElementAssumption> getChildElementAssumptions() {
    return Arrays.asList(
      new ChildElementAssumption(Question.class, 0, 1),
      new ChildElementAssumption(AllowedAnswers.class, 0, 1),
      new ChildElementAssumption(Variable.class, 0, 1),
      new ChildElementAssumption(InformationRequirement.class),
      new ChildElementAssumption(KnowledgeRequirement.class),
      new ChildElementAssumption(AuthorityRequirement.class),
      new ChildElementAssumption(SupportedObjectiveReference.class),
      new ChildElementAssumption(ImpactedPerformanceIndicatorReference.class),
      new ChildElementAssumption(DecisionMakerReference.class),
      new ChildElementAssumption(DecisionOwnerReference.class),
      new ChildElementAssumption(UsingProcessReference.class),
      new ChildElementAssumption(UsingTaskReference.class),
      new ChildElementAssumption(Expression.class, 0, 1)
    );
  }

  public Collection<AttributeAssumption> getAttributesAssumptions() {
    return null;
  }

}

==> camunda-dmn-model-7.7.0-test-sources.jar: org/camunda/bpm/model/dmn/instance/DecisionTest.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.camunda.bpm.model.dmn.instance;

import java.util.Arrays;
import java.util.Collection;
import static org.camunda.bpm.model.dmn.impl.DmnModelConstants.CAMUNDA_NS;

public class DecisionTest extends DmnModelElementInstanceTest {

  public TypeAssumption getTypeAssumption() {
    return new TypeAssumption(DrgElement.class, false);
  }

  public Collection<ChildElementAssumption> getChildElementAssumptions() {
    return Arrays.asList(
      new ChildElementAssumption(Question.class, 0, 1),
      new ChildElementAssumption(AllowedAnswers.class, 0, 1),
      new ChildElementAssumption(Variable.class, 0, 1),
      new ChildElementAssumption(InformationRequirement.class),
      new ChildElementAssumption(KnowledgeRequirement.class),
      new ChildElementAssumption(AuthorityRequirement.class),
      new ChildElementAssumption(SupportedObjectiveReference.class),
      new ChildElementAssumption(ImpactedPerformanceIndicatorReference.class),
      new ChildElementAssumption(DecisionMakerReference.class),
      new ChildElementAssumption(DecisionOwnerReference.class),
      new ChildElementAssumption(UsingProcessReference.class),
      new ChildElementAssumption(UsingTaskReference.class),
      new ChildElementAssumption(Expression.class, 0, 1)
    );
  }

  public Collection<AttributeAssumption> getAttributesAssumptions() {
    return Arrays.asList(
        new AttributeAssumption(CAMUNDA_NS, "historyTimeToLive"));
  }

}
